@@ -1,8 +1,28 @@
+"""
+Copyright (c) 2022 Poutyne and all respective contributors.
+
+Each contributor holds copyright over their respective contributions. The project versioning (Git)
+records all such contribution source information.
+
+This file is part of Poutyne.
+
+Poutyne is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
+version.
+
+Poutyne is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public License along with Poutyne. If not, see
+<https://www.gnu.org/licenses/>.
+"""
+
 import contextlib
 from collections import OrderedDict
 from itertools import islice, chain
 from math import cos, pi
 from typing import Dict, List, Tuple, Optional
+
 try:
     import matplotlib.pyplot as plt
 except ImportError:
@@ -95,10 +115,12 @@ class Phase:
             yield dict(zip(names, values))
 
     def __repr__(self):
-        return "\n".join([
-            "Phase:",
-            *["    {}: {}".format(name, val) for name, val in self.configuration.items()],
-        ])
+        return "\n".join(
+            [
+                "Phase:",
+                *[f"    {name}: {val}" for name, val in self.configuration.items()],
+            ]
+        )
 
     def plot(self, param_name: str = "lr", ax=None):
         """
@@ -125,11 +147,13 @@ class Phase:
 ###############################################################################
 # complex policies build from simple phases
 # pylint
-def one_cycle_phases(steps: int,
-                     lr: Tuple[float, float] = (0.1, 1),
-                     momentum: Tuple[float, float] = (0.95, 0.85),
-                     finetune_lr: float = .01,
-                     finetune_fraction: float = 0.1) -> List[Phase]:
+def one_cycle_phases(
+    steps: int,
+    lr: Tuple[float, float] = (0.1, 1),
+    momentum: Tuple[float, float] = (0.95, 0.85),
+    finetune_lr: float = 0.01,
+    finetune_fraction: float = 0.1,
+) -> List[Phase]:
     """
     The "one-cycle" policy as described in the paper `Super-Convergence: Very Fast Training of
     Neural Networks Using Large Learning Rates <https://arxiv.org/abs/1708.07120>`_.
@@ -172,10 +196,10 @@ def one_cycle_phases(steps: int,
 
 
 def sgdr_phases(
-        base_cycle_length: int,
-        cycles: int,
-        lr: Tuple[float, float] = (1., 0.1),
-        cycle_mult: int = 2,
+    base_cycle_length: int,
+    cycles: int,
+    lr: Tuple[float, float] = (1.0, 0.1),
+    cycle_mult: int = 2,
 ) -> List[Phase]:
     """
     The "SGDR" policy as described in the paper `SGDR: Stochastic Gradient Descent with Warm Restarts
@@ -247,7 +271,7 @@ class OptimizerPolicy(Callback):
         return chain.from_iterable(self.phases)
 
     def __repr__(self):
-        return "OptimizerPolicy:\n    phases: {}\n    current_step: {}".format(self.current_step, len(self.phases))
+        return f"OptimizerPolicy:\n    phases: {self.current_step}\n    current_step: {len(self.phases)}"
 
     def _update_optimizer(self, param_dict: Dict):
         for param_name, param_value in param_dict.items():
